==> digikam-2.2.0.tar.bz2: digikam-2.2.0/extra/kipi-plugins/photolayoutseditor/effectplugins/grayscale/GrayscalePhotoEffect.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2011-09-01
 * Description : a plugin to create photo layouts by fusion of several images.
 * Acknowledge : based on the expoblending plugin
 *
 * Copyright (C) 2011 by Łukasz Spas <lukasz dot spas at gmail dot com>
 * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "GrayscalePhotoEffect.moc"
#include "StarndardEffectsFactory.h"

#include <klocalizedstring.h>

using namespace KIPIPhotoLayoutsEditor;

GrayscalePhotoEffect::GrayscalePhotoEffect(StarndardEffectsFactory * factory, QObject * parent) :
    AbstractPhotoEffectInterface(factory, parent)
{
}

QImage GrayscalePhotoEffect::apply(const QImage & image) const
{
    if (!strength())
        return image;
    QImage result = image;
    QPainter p(&result);
    p.setCompositionMode(QPainter::CompositionMode_SourceOver);
    p.drawImage(0,0,AbstractPhotoEffectInterface::apply(greyscaled(image)));
    return result;
}

QString GrayscalePhotoEffect::name() const
{
    return i18n("Grayscale effect");
}

QString GrayscalePhotoEffect::toString() const
{
    return i18n("Grayscale effect");
}

GrayscalePhotoEffect::operator QString() const
{
    return toString();
}

==> digikam-2.4.0.tar.bz2: digikam-2.4.0/extra/kipi-plugins/photolayoutseditor/effectplugins/grayscale/GrayscalePhotoEffect.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2011-09-01
 * Description : a plugin to create photo layouts by fusion of several images.
 * Acknowledge : based on the expoblending plugin
 *
 * Copyright (C) 2011 by Łukasz Spas <lukasz dot spas at gmail dot com>
 * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "GrayscalePhotoEffect.moc"
#include "StandardEffectsFactory.h"

#include <klocalizedstring.h>

using namespace KIPIPhotoLayoutsEditor;

GrayscalePhotoEffect::GrayscalePhotoEffect(StandardEffectsFactory * factory, QObject * parent) :
    AbstractPhotoEffectInterface(factory, parent)
{
}

QImage GrayscalePhotoEffect::apply(const QImage & image) const
{
    if (!strength())
        return image;
    QImage result = image;
    QPainter p(&result);
    p.setCompositionMode(QPainter::CompositionMode_SourceOver);
    p.drawImage(0,0,AbstractPhotoEffectInterface::apply(greyscaled(image)));
    return result;
}

QString GrayscalePhotoEffect::name() const
{
    return i18n("Grayscale effect");
}

QString GrayscalePhotoEffect::toString() const
{
    return i18n("Grayscale effect");
}

GrayscalePhotoEffect::operator QString() const
{
    return toString();
}
